==> nextcloud-28.0.3.tgz: nextcloud/apps/logreader/l10n/es.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registros",
    "Errors in the log" : "Errores en los registros",
    "No errors in the logs since %s" : "No hay errores en los registros desde %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n error en los registros desde %s","%n errores en los registros desde %s","%n errores en los registros desde %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n advertencia en los registros desde %s","%n advertencias en los registros desde %s","%n advertencias en los registros desde %s"],
    "Log Reader" : "Lector del registro",
    "A log reader for Nextcloud" : "Un lector del registro para Nextcloud",
    "Log reader for Nextcloud" : "Lector del registro de Nextcloud",
    "Log reader" : "Lector del registro",
    "Open log reader settings" : "Abrir los ajustes del lector del registro",
    "Log reader settings" : "Ajustes del lector del registro",
    "Currently the log file {file} is shown" : "Actualmente se muestra el archivo de registro {file}",
    "Show server log" : "Mostrar registro del servidor",
    "Live view is disabled" : "La vista en vivo está deshabilitada",
    "No log file" : "Sin archivo de registro",
    "File-based logging must be enabled to access logs from the Web UI." : "El registro basado en archivo debe estar habilitado para acceder a los registros desde la interfaz Web.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Si siente que esto es un error, por favor verifique {setting} en su {config} y chequee el manual de administrador de Nextcloud.",
    "Level" : "Nivel",
    "App" : "Aplicación",
    "No app in context" : "No hay app en el contexto",
    "Time" : "Hora",
    "Copy raw entry" : "Copiar entrada en crudo",
    "Copy formatted entry" : "Copiar entrada formateada",
    "Hide exception details" : "Ocultar los detalles de la excepción",
    "View exception details" : "Ver los detalles de la excepción",
    "Raw log entry" : "Entrada del registro en crudo",
    "Log entry successfully copied" : "La entrada del registro fue copiada exitósamente",
    "Search log entries" : "Buscar en las entradas del registro",
    "Caused by {exception}" : "Causado por {exception}",
    "Line {line}" : "Línea {line}",
    "Filter log levels" : "Filtrar los niveles de registro",
    "Set log level" : "Establecer nivel de registro",
    "Time format" : "Formato horario",
    "Live view" : "Vista en vivo",
    "Download/Upload logs" : "Descargar/Subir registros",
    "Download logs" : "Descargar registros",
    "Show local log file" : "Mostrar archivo de registro local",
    "Upload local log file to be displayed" : "Cargar archivo de registro local para mostrar",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "No se pudo analizar el archivo de registro local",
    "Raw data" : "Datos en crudo",
    "Local time" : "Hora local",
    "UTC time" : "Hora UTC",
    "Time format used for displaying the timestamp" : "Formato horario a utilizar para mostrar la marca de tiempo",
    "(Local log files only support the \"raw\" time format)" : "(Los archivos de registro local sólo soportan el formato horario \"crudo\")",
    "Could not change date time format." : "No fue posible cambiar el formato horario.",
    "Polling is disabled because server is not configured to log to file" : "El sondeo está deshabilitado ya que el servidor no está configurado para escribir registros a archivo",
    "Polling (live view)" : "Sondeo (vista en vivo)",
    "Could not change live view setting." : "No fue posible cambiar la configuración de la vista en vivo.",
    "Filter logging levels" : "Filtrar niveles de registro",
    "Could not set logging levels to show" : "No fue posible establecer los niveles de registro a mostrar",
    "Set backend loglevel" : "Establecer nivel de registro del backend",
    "Could not set logging level" : "No se pudo establecer el nivel de registro",
    "Application" : "Aplicación",
    "Message" : "Mensaje",
    "Log entry actions" : "Acciones de entradas en registro",
    "Loading older log entries" : "Cargando entradas antiguas del registro",
    "No older log entries available" : "No hay entradas antiguas disponibles",
    "Collapse row" : "Colapsar fila",
    "Expand row" : "Expandir fila",
    "Show details" : "Mostrar detalles",
    "Debug" : "Depuración",
    "Info" : "Información",
    "Warning" : "Advertencia",
    "Error" : "Error",
    "Fatal" : "Fatal",
    "Could not load log entries" : "No se pudieron cargar entradas del registro",
    "Could not fetch new log entries (server unavailable)" : "No fue posible obtener nuevas entradas del registro (el servidor no está disponible)",
    "Could not fetch new entries" : "No fue posible obtener nuevas entradas",
    "Could not copy to clipboard, please copy manually:" : "No fue posible copiar al portapapeles, por favor, copie manualmente:",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} por {user} a las {time}\n",
    "Error parsing log" : "Error al analizar el registro",
    "Caused by " : "Causado por",
    "Copy" : "Copiar",
    "Copy raw" : "Copiar texto",
    "Copy formatted" : "Copiar con formato",
    "No server logs" : "No hay registros del servidor",
    "One or more entries are hidden by the log level filter" : "Una o más entradas están ocultas por el filtro de nivel del registro",
    "Everything is working fine" : "Todo está funcionando bien",
    "Load log file" : "Cargar archivo de registro",
    "Invalid log file" : "Archivo de registro no válido",
    "Log levels" : "Niveles de registro",
    "Log content" : "Contenido del registro",
    "Live update" : "Mostrar en directo",
    "line {line}" : "línea {line}",
    "Download / Upload logs" : "Descargar / Cargar registros"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-29.0.12.tgz: nextcloud/apps/logreader/l10n/es.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Registros",
    "Errors in the log" : "Errores en los registros",
    "Failed to get an iterator for log entries: %s" : "Fallo al obtener un iterador para las entradas en registro: %s",
    "No errors in the logs since %s" : "No hay errores en los registros desde %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : ["%n error en los registros desde %s","%n errores en los registros desde %s","%n errores en los registros desde %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n advertencia en los registros desde %s","%n advertencias en los registros desde %s","%n advertencias en los registros desde %s"],
    "Log Reader" : "Lector del registro",
    "A log reader for Nextcloud" : "Un lector del registro para Nextcloud",
    "Log reader for Nextcloud" : "Lector del registro de Nextcloud",
    "Log reader" : "Lector del registro",
    "Open log reader settings" : "Abrir los ajustes del lector del registro",
    "Log reader settings" : "Ajustes del lector del registro",
    "Currently the log file {file} is shown" : "Actualmente se muestra el archivo de registro {file}",
    "Show server log" : "Mostrar registro del servidor",
    "Live view is disabled" : "La vista en vivo está deshabilitada",
    "No log file" : "Sin archivo de registro",
    "File-based logging must be enabled to access logs from the Web UI." : "El registro basado en archivo debe estar habilitado para acceder a los registros desde la interfaz Web.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Si siente que esto es un error, por favor verifique {setting} en su {config} y chequee el manual de administrador de Nextcloud.",
    "Level" : "Nivel",
    "App" : "Aplicación",
    "No app in context" : "No hay app en el contexto",
    "Time" : "Hora",
    "Copy raw entry" : "Copiar entrada en crudo",
    "Copy formatted entry" : "Copiar entrada formateada",
    "Hide exception details" : "Ocultar los detalles de la excepción",
    "View exception details" : "Ver los detalles de la excepción",
    "Raw log entry" : "Entrada del registro en crudo",
    "Log entry successfully copied" : "La entrada del registro se ha copiado exitosamente",
    "Search log entries" : "Buscar en las entradas del registro",
    "Caused by {exception}" : "Causado por {exception}",
    "Line {line}" : "Línea {line}",
    "Filter log levels" : "Filtrar los niveles de registro",
    "Set log level" : "Establecer nivel de registro",
    "Time format" : "Formato horario",
    "Live view" : "Vista en vivo",
    "Download/Upload logs" : "Descargar/Subir registros",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "También puede mostrar entradas del registro copiadas desde el portapapeles copiando las mismas en la vista del registro usando: {keyboardShortcut}",
    "Download logs" : "Descargar registros",
    "Show local log file" : "Mostrar archivo de registro local",
    "Upload local log file to be displayed" : "Cargar archivo de registro local para mostrar",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "No se pudo analizar el archivo de registro local",
    "Raw data" : "Datos en crudo",
    "Local time" : "Hora local",
    "UTC time" : "Hora UTC",
    "Relative" : "Relativo",
    "Time format used for displaying the timestamp" : "Formato horario a utilizar para mostrar la marca de tiempo",
    "(Local log files only support the \"raw\" time format)" : "(Los archivos de registro local sólo soportan el formato horario \"crudo\")",
    "Could not change date time format." : "No fue posible cambiar el formato horario.",
    "Polling is disabled because server is not configured to log to file" : "El sondeo está deshabilitado ya que el servidor no está configurado para escribir registros a archivo",
    "Polling (live view)" : "Sondeo (vista en vivo)",
    "Could not change live view setting." : "No fue posible cambiar la configuración de la vista en vivo.",
    "Filter logging levels" : "Filtrar niveles de registro",
    "Could not set logging levels to show" : "No fue posible establecer los niveles de registro a mostrar",
    "Set backend loglevel" : "Establecer nivel de registro del backend",
    "Could not set logging level" : "No se pudo establecer el nivel de registro",
    "Application" : "Aplicación",
    "Message" : "Mensaje",
    "Log entry actions" : "Acciones de entradas en registro",
    "Loading older log entries" : "Cargando entradas antiguas del registro",
    "No older log entries available" : "No hay entradas antiguas disponibles",
    "Collapse row" : "Colapsar fila",
    "Expand row" : "Expandir fila",
    "Show details" : "Mostrar detalles",
    "Debug" : "Depuración",
    "Info" : "Información",
    "Warning" : "Advertencia",
    "Error" : "Error",
    "Fatal" : "Fatal",
    "Could not load log entries" : "No se pudieron cargar entradas del registro",
    "Clipboard" : "Portapapeles",
    "Could not parse clipboard content" : "No se pudo analizar el contenido del portapapeles ",
    "Could not fetch new log entries (server unavailable)" : "No fue posible obtener nuevas entradas del registro (el servidor no está disponible)",
    "Could not fetch new entries" : "No fue posible obtener nuevas entradas",
    "Could not copy to clipboard, please copy manually:" : "No fue posible copiar al portapapeles, por favor, copie manualmente:",
    "\tfrom {address} by {user} at {time}\n" : "\tde {address} por {user} a las {time}\n"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
